You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tomcat.apache.org by ma...@apache.org on 2021/07/22 14:56:35 UTC

[tomcat] branch 10.0.x updated: RejectHandler ->RejectPolicy for consistency. Correct Javadoc

This is an automated email from the ASF dual-hosted git repository.

markt pushed a commit to branch 10.0.x
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/10.0.x by this push:
     new 8bb0d1e  RejectHandler ->RejectPolicy for consistency. Correct Javadoc
8bb0d1e is described below

commit 8bb0d1e04bfbd5cc0ba3daebbcb66af7aa8cf5d5
Author: Mark Thomas <ma...@apache.org>
AuthorDate: Thu Jul 22 15:56:10 2021 +0100

    RejectHandler ->RejectPolicy for consistency. Correct Javadoc
---
 java/org/apache/tomcat/util/threads/ThreadPoolExecutor.java | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/java/org/apache/tomcat/util/threads/ThreadPoolExecutor.java b/java/org/apache/tomcat/util/threads/ThreadPoolExecutor.java
index 6f73fda..c8078f4 100644
--- a/java/org/apache/tomcat/util/threads/ThreadPoolExecutor.java
+++ b/java/org/apache/tomcat/util/threads/ThreadPoolExecutor.java
@@ -582,7 +582,7 @@ public class ThreadPoolExecutor extends AbstractExecutorService {
     /**
      * The default rejected execution handler.
      */
-    private static final RejectedExecutionHandler defaultHandler = new RejectHandler();
+    private static final RejectedExecutionHandler defaultHandler = new RejectPolicy();
 
     /**
      * Permission required for callers of shutdown and shutdownNow.
@@ -1212,7 +1212,7 @@ public class ThreadPoolExecutor extends AbstractExecutorService {
      * Creates a new {@code ThreadPoolExecutor} with the given initial
      * parameters, the
      * {@linkplain Executors#defaultThreadFactory default thread factory}
      * and the {@linkplain ThreadPoolExecutor.AbortPolicy
      * default rejected execution handler}.
      *
      * <p>It may be more convenient to use one of the {@link Executors}
@@ -1247,7 +1247,7 @@ public class ThreadPoolExecutor extends AbstractExecutorService {
 
     /**
      * Creates a new {@code ThreadPoolExecutor} with the given initial
      * parameters and the {@linkplain ThreadPoolExecutor.AbortPolicy
      * default rejected execution handler}.
      *
      * @param corePoolSize the number of threads to keep in the pool, even
@@ -2361,7 +2361,7 @@ public class ThreadPoolExecutor extends AbstractExecutorService {
         }
     }
 
-    private static class RejectHandler implements RejectedExecutionHandler {
+    private static class RejectPolicy implements RejectedExecutionHandler {
         @Override
         public void rejectedExecution(Runnable r, ThreadPoolExecutor executor) {
             throw new RejectedExecutionException();

---------------------------------------------------------------------
@@ -1212,7 +1212,7 @@ public class ThreadPoolExecutor extends AbstractExecutorService {
      * parameters, the
      * {@linkplain Executors#defaultThreadFactory default thread factory}
-     * and the {@linkplain ThreadPoolExecutor.AbortPolicy
+     * and the {@linkplain ThreadPoolExecutor.RejectPolicy
      * default rejected execution handler}.
      *
@@ -1247,7 +1247,7 @@ public class ThreadPoolExecutor extends AbstractExecutorService {
     /**
      * Creates a new {@code ThreadPoolExecutor} with the given initial
-     * parameters and the {@linkplain ThreadPoolExecutor.AbortPolicy
+     * parameters and the {@linkplain ThreadPoolExecutor.RejectPolicy
      * default rejected execution handler}.
      *
To unsubscribe, e-mail: dev-unsubscribe@tomcat.apache.org
For additional commands, e-mail: dev-help@tomcat.apache.org